==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/CorsPolicyFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CorsPolicyFluent<A extends CorsPolicyFluent<A>> extends Fluent<A>{
  public Boolean getAllowCredentials();
  public A withAllowCredentials(Boolean allowCredentials);
  public Boolean hasAllowCredentials();
  public A addToAllowHeaders(Integer index,String item);
  public A setToAllowHeaders(Integer index,String item);
  public A addToAllowHeaders(java.lang.String... items);
  public A addAllToAllowHeaders(Collection<String> items);
  public A removeFromAllowHeaders(java.lang.String... items);
  public A removeAllFromAllowHeaders(Collection<String> items);
  public List<String> getAllowHeaders();
  public String getAllowHeader(Integer index);
  public String getFirstAllowHeader();
  public String getLastAllowHeader();
  public String getMatchingAllowHeader(Predicate<String> predicate);
  public Boolean hasMatchingAllowHeader(Predicate<String> predicate);
  public A withAllowHeaders(List<String> allowHeaders);
  public A withAllowHeaders(java.lang.String... allowHeaders);
  public Boolean hasAllowHeaders();
  public A addToAllowMethods(Integer index,String item);
  public A setToAllowMethods(Integer index,String item);
  public A addToAllowMethods(java.lang.String... items);
  public A addAllToAllowMethods(Collection<String> items);
  public A removeFromAllowMethods(java.lang.String... items);
  public A removeAllFromAllowMethods(Collection<String> items);
  public List<String> getAllowMethods();
  public String getAllowMethod(Integer index);
  public String getFirstAllowMethod();
  public String getLastAllowMethod();
  public String getMatchingAllowMethod(Predicate<String> predicate);
  public Boolean hasMatchingAllowMethod(Predicate<String> predicate);
  public A withAllowMethods(List<String> allowMethods);
  public A withAllowMethods(java.lang.String... allowMethods);
  public Boolean hasAllowMethods();
  public A addToDeprecatedAllowOrigin(Integer index,String item);
  public A setToDeprecatedAllowOrigin(Integer index,String item);
  public A addToDeprecatedAllowOrigin(java.lang.String... items);
  public A addAllToDeprecatedAllowOrigin(Collection<String> items);
  public A removeFromDeprecatedAllowOrigin(java.lang.String... items);
  public A removeAllFromDeprecatedAllowOrigin(Collection<String> items);
  public List<String> getDeprecatedAllowOrigin();
  public String getDeprecatedAllowOrigin(Integer index);
  public String getFirstDeprecatedAllowOrigin();
  public String getLastDeprecatedAllowOrigin();
  public String getMatchingDeprecatedAllowOrigin(Predicate<String> predicate);
  public Boolean hasMatchingDeprecatedAllowOrigin(Predicate<String> predicate);
  public A withDeprecatedAllowOrigin(List<String> deprecatedAllowOrigin);
  public A withDeprecatedAllowOrigin(java.lang.String... deprecatedAllowOrigin);
  public Boolean hasDeprecatedAllowOrigin();
  public A addToAllowOrigins(Integer index,StringMatch item);
  public A setToAllowOrigins(Integer index,StringMatch item);
  public A addToAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... items);
  public A addAllToAllowOrigins(Collection<StringMatch> items);
  public A removeFromAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... items);
  public A removeAllFromAllowOrigins(Collection<StringMatch> items);
  public A removeMatchingFromAllowOrigins(Predicate<StringMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllowOrigins instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<StringMatch> getAllowOrigins();
  public List<StringMatch> buildAllowOrigins();
  public StringMatch buildAllowOrigin(Integer index);
  public StringMatch buildFirstAllowOrigin();
  public StringMatch buildLastAllowOrigin();
  public StringMatch buildMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public Boolean hasMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public A withAllowOrigins(List<StringMatch> allowOrigins);
  public A withAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... allowOrigins);
  public Boolean hasAllowOrigins();
  public CorsPolicyFluent.AllowOriginsNested<A> addNewAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> addNewAllowOriginLike(StringMatch item);
  public CorsPolicyFluent.AllowOriginsNested<A> setNewAllowOriginLike(Integer index,StringMatch item);
  public CorsPolicyFluent.AllowOriginsNested<A> editAllowOrigin(Integer index);
  public CorsPolicyFluent.AllowOriginsNested<A> editFirstAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> editLastAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> editMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public A addToExposeHeaders(Integer index,String item);
  public A setToExposeHeaders(Integer index,String item);
  public A addToExposeHeaders(java.lang.String... items);
  public A addAllToExposeHeaders(Collection<String> items);
  public A removeFromExposeHeaders(java.lang.String... items);
  public A removeAllFromExposeHeaders(Collection<String> items);
  public List<String> getExposeHeaders();
  public String getExposeHeader(Integer index);
  public String getFirstExposeHeader();
  public String getLastExposeHeader();
  public String getMatchingExposeHeader(Predicate<String> predicate);
  public Boolean hasMatchingExposeHeader(Predicate<String> predicate);
  public A withExposeHeaders(List<String> exposeHeaders);
  public A withExposeHeaders(java.lang.String... exposeHeaders);
  public Boolean hasExposeHeaders();
  public String getMaxAge();
  public A withMaxAge(String maxAge);
  public Boolean hasMaxAge();
  public A withAllowCredentials();
  public interface AllowOriginsNested<N> extends Nested<N>,StringMatchFluent<CorsPolicyFluent.AllowOriginsNested<N>>{
    public N and();
    public N endAllowOrigin();
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/CorsPolicyFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface CorsPolicyFluent<A extends CorsPolicyFluent<A>> extends Fluent<A>{
  public Boolean getAllowCredentials();
  public A withAllowCredentials(Boolean allowCredentials);
  public Boolean hasAllowCredentials();
  public A addToAllowHeaders(int index,String item);
  public A setToAllowHeaders(int index,String item);
  public A addToAllowHeaders(java.lang.String... items);
  public A addAllToAllowHeaders(Collection<String> items);
  public A removeFromAllowHeaders(java.lang.String... items);
  public A removeAllFromAllowHeaders(Collection<String> items);
  public List<String> getAllowHeaders();
  public String getAllowHeader(int index);
  public String getFirstAllowHeader();
  public String getLastAllowHeader();
  public String getMatchingAllowHeader(Predicate<String> predicate);
  public Boolean hasMatchingAllowHeader(Predicate<String> predicate);
  public A withAllowHeaders(List<String> allowHeaders);
  public A withAllowHeaders(java.lang.String... allowHeaders);
  public Boolean hasAllowHeaders();
  public A addToAllowMethods(int index,String item);
  public A setToAllowMethods(int index,String item);
  public A addToAllowMethods(java.lang.String... items);
  public A addAllToAllowMethods(Collection<String> items);
  public A removeFromAllowMethods(java.lang.String... items);
  public A removeAllFromAllowMethods(Collection<String> items);
  public List<String> getAllowMethods();
  public String getAllowMethod(int index);
  public String getFirstAllowMethod();
  public String getLastAllowMethod();
  public String getMatchingAllowMethod(Predicate<String> predicate);
  public Boolean hasMatchingAllowMethod(Predicate<String> predicate);
  public A withAllowMethods(List<String> allowMethods);
  public A withAllowMethods(java.lang.String... allowMethods);
  public Boolean hasAllowMethods();
  public A addToDeprecatedAllowOrigin(int index,String item);
  public A setToDeprecatedAllowOrigin(int index,String item);
  public A addToDeprecatedAllowOrigin(java.lang.String... items);
  public A addAllToDeprecatedAllowOrigin(Collection<String> items);
  public A removeFromDeprecatedAllowOrigin(java.lang.String... items);
  public A removeAllFromDeprecatedAllowOrigin(Collection<String> items);
  public List<String> getDeprecatedAllowOrigin();
  public String getDeprecatedAllowOrigin(int index);
  public String getFirstDeprecatedAllowOrigin();
  public String getLastDeprecatedAllowOrigin();
  public String getMatchingDeprecatedAllowOrigin(Predicate<String> predicate);
  public Boolean hasMatchingDeprecatedAllowOrigin(Predicate<String> predicate);
  public A withDeprecatedAllowOrigin(List<String> deprecatedAllowOrigin);
  public A withDeprecatedAllowOrigin(java.lang.String... deprecatedAllowOrigin);
  public Boolean hasDeprecatedAllowOrigin();
  public A addToAllowOrigins(int index,StringMatch item);
  public A setToAllowOrigins(int index,StringMatch item);
  public A addToAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... items);
  public A addAllToAllowOrigins(Collection<StringMatch> items);
  public A removeFromAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... items);
  public A removeAllFromAllowOrigins(Collection<StringMatch> items);
  public A removeMatchingFromAllowOrigins(Predicate<StringMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAllowOrigins instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<StringMatch> getAllowOrigins();
  public List<StringMatch> buildAllowOrigins();
  public StringMatch buildAllowOrigin(int index);
  public StringMatch buildFirstAllowOrigin();
  public StringMatch buildLastAllowOrigin();
  public StringMatch buildMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public Boolean hasMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public A withAllowOrigins(List<StringMatch> allowOrigins);
  public A withAllowOrigins(io.fabric8.istio.api.networking.v1beta1.StringMatch... allowOrigins);
  public Boolean hasAllowOrigins();
  public CorsPolicyFluent.AllowOriginsNested<A> addNewAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> addNewAllowOriginLike(StringMatch item);
  public CorsPolicyFluent.AllowOriginsNested<A> setNewAllowOriginLike(int index,StringMatch item);
  public CorsPolicyFluent.AllowOriginsNested<A> editAllowOrigin(int index);
  public CorsPolicyFluent.AllowOriginsNested<A> editFirstAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> editLastAllowOrigin();
  public CorsPolicyFluent.AllowOriginsNested<A> editMatchingAllowOrigin(Predicate<StringMatchBuilder> predicate);
  public A addToExposeHeaders(int index,String item);
  public A setToExposeHeaders(int index,String item);
  public A addToExposeHeaders(java.lang.String... items);
  public A addAllToExposeHeaders(Collection<String> items);
  public A removeFromExposeHeaders(java.lang.String... items);
  public A removeAllFromExposeHeaders(Collection<String> items);
  public List<String> getExposeHeaders();
  public String getExposeHeader(int index);
  public String getFirstExposeHeader();
  public String getLastExposeHeader();
  public String getMatchingExposeHeader(Predicate<String> predicate);
  public Boolean hasMatchingExposeHeader(Predicate<String> predicate);
  public A withExposeHeaders(List<String> exposeHeaders);
  public A withExposeHeaders(java.lang.String... exposeHeaders);
  public Boolean hasExposeHeaders();
  public String getMaxAge();
  public A withMaxAge(String maxAge);
  public Boolean hasMaxAge();
  public A withAllowCredentials();
  public interface AllowOriginsNested<N> extends Nested<N>,StringMatchFluent<CorsPolicyFluent.AllowOriginsNested<N>>{
    public N and();
    public N endAllowOrigin();
    
  }
  
}
